//
// Copyright 2025 Signal Messenger, LLC.
// SPDX-License-Identifier: AGPL-3.0-only
//

#![warn(clippy::unwrap_used)]

pub mod api;
pub mod grpc;
mod logging;
pub mod registration;
pub mod ws;
